// Benchmark.js - https://github.com/mathiasbynens/benchmark.js
var Benchmark = require('benchmark')
  , suite = new Benchmark.Suite
  , words = [ 'kitten', 'smitten' ]

/* ------------------------------ Implementation: gf3 ------------------------------ */
var gf3 =
  { levenshtein: require( '../lib/levenshtein' )
  , test: function() {
      var l = gf3.levenshtein( words[0], words[1] )
    }
  }

/* ------------------------------ Implementation: Andrew Hedges ------------------------------ */
var andrew_hedges =
  { levenshtein: require( './implementations/levenshtein.andrew_hedges' )
  , fob: { string_a: { value: words[0] }, string_b: { value: words[1] } }
  , test: function() {
      var l = andrew_hedges.levenshtein( andrew_hedges.fob )
    }
  }

/* ------------------------------ PHPJS ------------------------------ */
var phpjs =
  { levenshtein: require( './implementations/levenshtein.phpjs' )
  , test: function() {
      var l = phpjs.levenshtein( words[0], words[1] )
    }
  }
  
/* ------------------------------ Run! ------------------------------ */
suite
  .add( 'gf3', gf3.test )
  .add( 'Andrew Hedges', andrew_hedges.test )
  .add( 'phpjs', phpjs.test )
  .on( 'cycle', function( bench ) { console.log( bench.toString() ) } )
  .on( 'complete', function() { console.log( 'Fastest is ' + this.filter( 'fastest' ).pluck( 'name' ) ) } )
  .run( true )

